<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://www.spip.net/de',
'0_langue' => 'Deutsch [de]',
'0_liste' => 'spip-de@rezo.net',
'0_mainteneur' => 'klaus@spip.de',

// A
'access_interface_graphique' => 'Zur&uuml;ck zur vollst&auml;ndigen grafischen Oberfl&auml;che',
'access_mode_texte' => 'vereinfachtes Interface als Textversion anzeigen',
'admin_debug' => 'Debug',
'admin_modifier_article' => 'Artikel bearbeiten',
'admin_modifier_auteur' => 'Autor bearbeiten',
'admin_modifier_breve' => 'Meldung bearbeiten',
'admin_modifier_mot' => 'Schlagwort bearbeiten',
'admin_modifier_rubrique' => 'Rubrik bearbeiten',
'admin_recalculer' => 'Seite aus Cache l&ouml;schen',
'afficher_trad' => '&Uuml;bersetzungen anzeigen',
'alerte_maj_impossible' => '<b>Achtung!</b> Ihre SQL Datenbank konnte nicht auf die Version @version@ umgestellt werden. M&ouml;glicherweise gibt es ein Problem mit den Zugriffsrechten. Bitte setzen Sie sich mit Ihrem Webspace-Provider in Verbindung.',
'alerte_modif_info_concourante' => 'Achtung - diese Information wurde auf anderem Weg modifiziert. Der aktuelle Wert lautet:',
'analyse_xml' => 'XML-Analyse',
'annuler' => 'Abbrechen',
'antispam_champ_vide' => 'Bitte lassen Sie dieses Feld leer:',
'articles_recents' => 'Die neuesten Artikel',
'avis_archive_incorrect' => 'Die archivierte Datei ist keine SPIP-Datei',
'avis_archive_invalide' => 'Die archivierte Datei ist keine SPIP-Datei',
'avis_attention' => 'ACHTUNG!',
'avis_champ_incorrect_type_objet' => 'Falscher Objektname @name@ f&uuml;r Objekt vom Typ @type@',
'avis_colonne_inexistante' => 'Die Spalte @col@ existiert nicht',
'avis_echec_syndication_01' => 'Syndikation fehlgeschlagen: Die Backend-Datei konnte nicht gelesen werden oder enth&auml;lt keinen Artikel.',
'avis_echec_syndication_02' => 'Syndikation fehlgeschlagen: Backend-Datei dieser Website ist nicht erreichbar.',
'avis_erreur' => 'Fehler: Siehe unten',
'avis_erreur_connexion' => 'Verbindungsfehler',
'avis_erreur_cookie' => 'Cookie-Problem',
'avis_erreur_fonction_contexte' => 'Programmfehler. Diese Funktion darf nicht in diesem Zusammenhang aufgerufen werden.',
'avis_erreur_mysql' => 'SQL-Fehler',
'avis_erreur_sauvegarde' => 'Fehler in der Sicherung (@type@ @id_objet@) ! ',
'avis_erreur_visiteur' => 'Ein Problem beim Zugang zum Redaktionssystem ist aufgetreten.',

// B
'barre_a_accent_grave' => 'Grosses A mit accent grave einf&uuml;gen',
'barre_aide' => 'Verwende Sie die typografischen K&uuml;rzel, um Ihre Seite zu formatieren.',
'barre_e_accent_aigu' => 'Grosses E mit accent aigu einf&uuml;gen',
'barre_eo' => 'Ein E in das O einf&uuml;gen',
'barre_eo_maj' => 'Ein E in ein grosses O einf&uuml;gen',
'barre_euro' => 'Symbol &euro; einf&uuml;gen',
'barre_gras' => '{{fett}} setzen',
'barre_guillemets' => 'In &bdquo;Anf&uuml;hrungszeichen&ldquo; setzen',
'barre_guillemets_simples' => 'In &sbquo;Anf&uuml;hrungszeichen&lsquo; setzen',
'barre_intertitre' => 'in {{{Zwischentitel}}} umwandeln',
'barre_italic' => 'in {kursive} Schrift setzen',
'barre_lien' => 'in [Hyperlink->http://...] umwandeln',
'barre_lien_input' => 'Bitte geben Sie die Adresse Ihres Links an. Sie k&ouml;nnen das Format http://www.meinewebsite.com w&auml;hlen, oder einfach die Nummer eines Artikels dieser Website angeben.',
'barre_note' => 'In [[Fussnote]] umwandeln',
'barre_paragraphe' => 'Neuen Absatz anlegen',
'barre_quote' => '<quote>Nachricht zitieren</quote>',
'bouton_ajouter_document' => 'Dokument hinzuf&uuml;gen',
'bouton_ajouter_image' => 'Bild hinzuf&uuml;gen',
'bouton_ajouter_image_document' => 'Bild oder Dokument hinzuf&uuml;gen',
'bouton_changer' => '&Auml;ndern',
'bouton_chercher' => 'Suchen',
'bouton_choisir' => 'Ausw&auml;hlen',
'bouton_download' => '&Uuml;bertragen',
'bouton_enregistrer' => 'Speichern',
'bouton_radio_desactiver_messagerie_interne' => 'Interne Nachrichten abschalten',
'bouton_radio_envoi_annonces' => 'Editorische Ank&uuml;ndigungen verschicken',
'bouton_radio_non_envoi_annonces' => 'Keine Ank&uuml;ndigungen verschicken',
'bouton_radio_non_envoi_liste_nouveautes' => 'Keine Liste der Neuigkeiten verschicken',
'bouton_recharger_page' => 'Seite neu laden',
'bouton_telecharger' => 'Herunterladen',
'bouton_valider' => 'Best&auml;tigen',

// C
'cal_apresmidi' => 'nachmittags',
'cal_jour_entier' => 'ganzt&auml;gig',
'cal_matin' => 'morgens',
'cal_par_jour' => 'Tageskalender',
'cal_par_mois' => 'Monatskalender',
'cal_par_semaine' => 'Wochenkalender',
'choix_couleur_interface' => 'Farbe',
'choix_interface' => 'Oberfl&auml;chenfarbe',
'colonne' => 'Spalte',
'confirm_changer_statut' => 'Achtung, Sie werden den Status dieses Elementes &auml;ndern. Wollen Sie fortfahren?',
'correcte' => 'korrekt',

// D
'date_aujourdhui' => 'heute',
'date_avant_jc' => 'v.u.Z.',
'date_dans' => 'in @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'morgen',
'date_fmt_heures_minutes' => '@h@&nbsp;Uhr&nbsp;@m@&nbsp;Minuten',
'date_fmt_jour_heure' => '@jour@ um @heure@',
'date_fmt_jour_mois' => '@jour@.&nbsp;@nommois@',
'date_fmt_jour_mois_annee' => '@jour@.&nbsp;@nommois@&nbsp;@annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'am @nomjour@ @date@',
'date_heures' => 'Stunden',
'date_hier' => 'gestern',
'date_il_y_a' => 'vor @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Sonntag',
'date_jour_1_abbr' => 'So.',
'date_jour_1_initiale' => 'S',
'date_jour_2' => 'Montag',
'date_jour_2_abbr' => 'Mo.',
'date_jour_2_initiale' => 'M',
'date_jour_3' => 'Dienstag',
'date_jour_3_abbr' => 'Di.',
'date_jour_3_initiale' => 'D',
'date_jour_4' => 'Mittwoch',
'date_jour_4_abbr' => 'Mi.',
'date_jour_4_initiale' => 'M',
'date_jour_5' => 'Donnerstag',
'date_jour_5_abbr' => 'Do.',
'date_jour_5_initiale' => 'D',
'date_jour_6' => 'Freitag',
'date_jour_6_abbr' => 'Fr.',
'date_jour_6_initiale' => 'F',
'date_jour_7' => 'Sonnabend',
'date_jour_7_abbr' => 'Sa.',
'date_jour_7_initiale' => 'S',
'date_jours' => 'Tagen',
'date_minutes' => 'Minuten',
'date_mois' => 'Monaten',
'date_mois_1' => 'Januar',
'date_mois_10' => 'Oktober',
'date_mois_11' => 'November',
'date_mois_12' => 'Dezember',
'date_mois_2' => 'Februar',
'date_mois_3' => 'M&auml;rz',
'date_mois_4' => 'April',
'date_mois_5' => 'Mai',
'date_mois_6' => 'Juni',
'date_mois_7' => 'Juli',
'date_mois_8' => 'August',
'date_mois_9' => 'September',
'date_saison_1' => 'Winter',
'date_saison_2' => 'Fr&uuml;hling',
'date_saison_3' => 'Sommer',
'date_saison_4' => 'unabh&auml;ngig',
'date_secondes' => 'Sekunden',
'date_semaines' => 'Wochen',
'date_un_mois' => 'Monat',
'date_une_heure' => 'Stunde',
'date_une_minute' => 'Minute',
'date_une_seconde' => 'Sekunde',
'date_une_semaine' => 'Woche',
'dirs_commencer' => 'um die Installation wirklich zu starten',
'dirs_preliminaire' => 'Vorbereitung: <b>Berechtigungen einstellen</b>',
'dirs_probleme_droits' => 'Problem mit den Berechtigungen',
'dirs_repertoires_absents' => '<p><b>Folgende Verzeichnisse wurden nicht gefunden:</b></p><ul>@bad_dirs@</ul>
  <p>Das liegt wahrscheinlich an unzutreffender Gross- und Kleinschreibung.
  &Uuml;berpr&uuml;fen Sie bitte die genaue Schreibweise der oben stehenden Verzeichnisse,
  sollten Sie Abweichungen feststellen, benennen Sie bitte mit Ihrem FTP-Programm die betreffenden Verzeichnisse um.</p>
  <p>Danach k&ouml;nnen Sie ',
'dirs_repertoires_suivants' => '<p><b>In die folgenden Verzeichnisse kann nicht geschrieben werden:</b></p><ul>@bad_dirs@</ul>
<p>Um das Problem zu l&ouml;sen, verwenden Sie bitte Ihren FTP-Client, um die Zugriffsrechte f&uuml;r diese
Verzeichnisse zu setzen.Die Installationsanleitung erl&auml;utert die Details dazu.</p>
<p>Wenn Sie diesen Vorgang abgeschlossen haben, k&ouml;nnen Sie',
'double_occurrence' => 'Dublette von @balise@',

// E
'en_cours' => 'l&auml;uft',
'entree_dimensions' => 'Gr&ouml;ssenangaben:',
'entree_titre_document' => 'Titel des Dokuments:',
'entree_titre_image' => 'Titel des Bilds:',
'envoi_via_le_site' => 'Gesendet &uuml;ber Website ',
'erreur' => 'Fehler',
'erreur_balise_non_fermee' => 'Letzter Tag nicht geschlossen:',
'erreur_texte' => 'Fehler',
'etape' => 'Schritt',

// F
'fichier_introuvable' => 'Datei @fichier@ unauffindbar',
'form_auteur_confirmation' => 'Best&auml;tigen Sie Ihre Mailadresse',
'form_auteur_email_modifie' => 'Ihre Mailadresse wurde ge&auml;ndert.',
'form_auteur_envoi_mail_confirmation' => 'Eine Mail wurde an @email@ gesendet. Sie m&uuml;ssen auf den in ihr angegebenen Link klicken, um die Korrektheit Ihrer Adresse zu best&auml;tigen.',
'form_auteur_mail_confirmation' => 'Hallo,

Sie m&ouml;chten Ihre Mail-Adresse &auml;ndern.Um Ihre neue Adresse zu best&auml;tigen,
 brauchen Sie nur diesen Link zu &ouml;ffnen (wenn Sie darauf verzichten,
wird Ihre Adresse beibehalten):

    @url@
',
'form_deja_inscrit' => 'Sie sind bereits eingetragen.',
'form_email_non_valide' => 'Ihre E-Mail-Adresse ist ung&uuml;ltig.',
'form_forum_access_refuse' => 'Sie haben keinen Zugang mehr zu dieser Website.',
'form_forum_bonjour' => 'Hallo @nom@,',
'form_forum_email_deja_enregistre' => 'Diese E-Mail-Adresse ist bereits eingetragen. Sie k&ouml;nnen also Ihr normals Passwort verwenden.',
'form_forum_identifiant_mail' => 'Ihre neuen Zugangsdaten wurden Ihnen per Mail zugestellt.',
'form_forum_identifiants' => 'Pers&ouml;nliche Zugangsdaten',
'form_forum_indiquer_nom_email' => 'Tragen Sie bitte hier Ihren Namen und Ihre E-Mail-Adresse ein. Die pers&ouml;nlichen Zugangsdaten werden Ihnen dann per E-Mail zugeschickt.',
'form_forum_login' => 'Login:',
'form_forum_message_auto' => '(automatisch erzeugte Nachricht)',
'form_forum_pass' => 'Passwort:',
'form_forum_probleme_mail' => 'E-Mail Problem: Zugangsdaten k&ouml;nnen nicht verschickt werden.',
'form_forum_voici1' => 'Hier sind Ihre Zugangsdaten f&uuml;r die Teilnahme an der Website "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Hier sind Ihre Zugangsdaten um Artikel f&uuml;r die Website "@nom_site_spip@" (@adresse_login@) vorzuschlagen:',
'form_indiquer_email' => 'Bitte geben Sie Ihre E-Mail-Adresse an.',
'form_indiquer_nom' => 'Bitte geben Sie Ihren Namen an.',
'form_indiquer_nom_site' => 'Bitte geben Sie den Namen Ihrer Website an.',
'form_pet_adresse_site' => 'Adresse Ihrer Website',
'form_pet_aucune_signature' => 'Diesem Code entspricht keine Signatur...',
'form_pet_confirmation' => 'Bitte best&auml;tigen Sie Ihre Unterschrift:',
'form_pet_deja_enregistre' => 'Diese Website wurde bereits erfasst',
'form_pet_deja_signe' => 'Sie haben diesen Text bereits unterschrieben.',
'form_pet_envoi_mail_confirmation' => 'Eine E-mail mit den Daten zum Best&auml;tigen wurde an @email@ geschickt. Sie m&uuml;ssen die dort angegebene WWW-Seite &ouml;ffnen, um Ihre Unterschrift zu best&auml;tigen.',
'form_pet_mail_confirmation' => 'Hallo,

Sie m&ouml;chten diese Petition unterzeichnen:
@titre@.

Sie haben die folgenden Angaben gemacht:
    Name: @nom_email@
    Website: @nom_site@ - @url_site@
    @message@

ACHTUNG:
Um Ihre Unterschrift zu best&auml;tigen m&uuml;ssen Sie diese Seite aufrufen (wenn Sie es nicht tun, wird Ihre Unterschrift verworfen):

    @url@


Vielen Dank f&uuml;r Ihre Teilnahme
',
'form_pet_message_commentaire' => 'Eine Nachricht, ein Kommentar?',
'form_pet_nom_site2' => 'Name Ihrer Website',
'form_pet_probleme_liens' => 'Bitte entfernen Sie die Hyperlinks aus Ihrer Nachricht.',
'form_pet_probleme_technique' => 'Technisches Problem: Signaturen sind vor&uuml;bergehend nicht m&ouml;glich.',
'form_pet_signature_pasprise' => 'Ihre Signatur wird nicht ber&uuml;cksichtigt.',
'form_pet_signature_validee' => 'Ihre Signatur wurde erfolgreich gepr&uuml;ft. Vielen Dank!',
'form_pet_site_deja_enregistre' => 'Diese Website wurde bereits erfasst',
'form_pet_url_invalide' => 'Sie haben einen ung&uuml;ltigen URL angegeben.',
'form_pet_votre_email' => 'Ihre E-Mail Adresse',
'form_pet_votre_nom' => 'Ihr Name oder Pseudonym',
'form_pet_votre_site' => 'Wenn Sie eine eigene Website haben, k&ouml;nnen Sie sie hier eintragen',
'form_prop_confirmer_envoi' => 'Senden',
'form_prop_description' => 'Beschreibung/Kommentar',
'form_prop_enregistre' => 'Ihr Vorschlag wurde gespeichert und wird nach Freigabe durch die Redaktion der Website angezeigt.',
'form_prop_envoyer' => 'Nachricht senden',
'form_prop_indiquer_email' => 'Bitte geben Sie eine g&uuml;ltige E-Mail Adresse an',
'form_prop_indiquer_nom_site' => 'Bitte geben Sie den Namen der Website an.',
'form_prop_indiquer_sujet' => 'Bitte geben Sie ein Thema an',
'form_prop_message_envoye' => 'Nachricht gesendet',
'form_prop_nom_site' => 'Name der Website',
'form_prop_non_enregistre' => 'Ihr Vorschlag wurde nicht gespeichert.',
'form_prop_sujet' => 'Thema',
'form_prop_url_site' => 'Adresse (URL) der Website',
'forum_acces_refuse' => 'Sie haben keinen Zugang mehr zu diesen Foren.',
'forum_attention_dix_caracteres' => '<b>Achtung!</b> Ihr Beitrag ist muss mindestens 10 Zeichen lang sein.',
'forum_attention_trois_caracteres' => '<b>Achtung!</b> Ihr Titel muss mindestens drei Zeichen lang sein.',
'forum_attention_trop_caracteres' => '<b>Achtung!</b> Ihr Beitrag ist zu lang (@compte@ Zeichen). Damit er gespeichert werden kann, darf er maximal @max@ Zeichen lang sein.',
'forum_avez_selectionne' => 'Sie haben ausgew&auml;hlt:',
'forum_cliquer_retour' => '<a href=\'@retour_forum@\'>Weiter</a>',
'forum_forum' => 'Forum',
'forum_info_modere' => 'Dieses Forum ist moderiert. Ihr Beitrag erscheint erst nach Freischaltung durch einen Administrator der Website.',
'forum_lien_hyper' => '<b>Hyperlink</b> (optional)',
'forum_message_definitif' => 'Beitrag fertiggestellt: Endg&uuml;ltig eintragen.',
'forum_message_trop_long' => 'Ihr Beitrag ist zu lang. Sie k&ouml;nnen maximal 20.000 Zeichen schreiben.',
'forum_ne_repondez_pas' => 'Antworten Sie nicht auf diese Mail, sondern im Forum mit dieser Adresse:',
'forum_non_inscrit' => 'Sie sind nicht eingeschrieben oder Adresse bzw. Passwort waren falsch.',
'forum_page_url' => '(Wenn sich Ihr Beitrag auf einen Artikel im Internet oder auf eine Seite mit Zusatzinformationen bezieht, geben Sie hier bitte den Titel der Seite und ihre Adresse bzw. URL an.)',
'forum_par_auteur' => 'Nach @auteur@',
'forum_poste_par' => 'Beitrag von @parauteur@ als Antwort auf den Artikel &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Datenbankfehler. Ihr Beitrag wurde nicht gespeichert',
'forum_qui_etes_vous' => '<b>Wer sind Sie?</b> (optional)',
'forum_texte' => 'Text Ihres Beitrags:',
'forum_titre' => 'Titel:',
'forum_titre_erreur' => 'Fehler...',
'forum_url' => 'URL:',
'forum_valider' => 'Auswahl best&auml;tigen',
'forum_voir_avant' => 'Nachricht vor Ver&ouml;ffentlichung ansehen',
'forum_votre_email' => 'Ihr E-Mail Adresse:',
'forum_votre_nom' => 'Ihr Name (oder Pseudonym) :',
'forum_vous_enregistrer' => 'Um an diesem Forum teilnehmen zu k&ouml;nnen, m&uuml;ssen Sie sich anmelden. Bitte tragen Sie weiter unten die Zugangsdaten ein, die Sie per Mail erhalten haben. Wenn Sie noch nicht angemeldet sind, k&ouml;nnen Sie sich',
'forum_vous_inscrire' => 'online anmelden.',

// I
'ical_texte_rss_articles' => 'Die &laquo;backend&raquo; Datei mit den Artikeln der Website finden Sie unter dieser Adresse:',
'ical_texte_rss_articles2' => 'Sie k&ouml;nnen auch &laquo;backend&raquo; Dateien f&uuml;r einzelne Rubriken de Website nutzen:',
'ical_texte_rss_breves' => 'Es gibt ebenfalls eine Datei f&uuml;r die Meldungen der Website. Wenn Sie die Nummer (ID) einer Rubrik angeben, erhalten Sie auchsschliesslich die Meldungen aus dieser Rubrik.',
'icone_a_suivre' => 'Aufgaben',
'icone_admin_site' => 'Konfiguration',
'icone_agenda' => 'Kalender',
'icone_aide_ligne' => 'Online-Hilfe',
'icone_articles' => 'Artikel',
'icone_auteurs' => 'Autoren',
'icone_breves' => 'Meldungen',
'icone_brouteur' => '&Uuml;bersicht',
'icone_configuration_site' => 'Konfiguration',
'icone_configurer_site' => 'Ihre Website konfigurieren',
'icone_creer_nouvel_auteur' => 'Neuen Autor anlegen',
'icone_creer_rubrique' => 'Neue Rubrik anlegen',
'icone_creer_sous_rubrique' => 'Neue Unterrubrik anlegen',
'icone_deconnecter' => 'Log-Out',
'icone_discussions' => 'Diskussionen',
'icone_doc_rubrique' => 'Dokumente der Rubriken',
'icone_ecrire_article' => 'Neuen Artikel schreiben',
'icone_edition_site' => 'Redaktion',
'icone_forum_administrateur' => 'Forum der Administratoren',
'icone_forum_suivi' => 'Foren moderieren',
'icone_gestion_langues' => 'Sprachverwaltung',
'icone_informations_personnelles' => 'Pers&ouml;nliche Informationen',
'icone_interface_complet' => 'Expertenmodus',
'icone_interface_simple' => 'Standardmodus',
'icone_maintenance_site' => 'Wartung',
'icone_messagerie_personnelle' => 'Pers&ouml;nliche Nachrichten',
'icone_mots_cles' => 'Schlagworte',
'icone_nouvelle_breve' => 'Neue Meldung schreiben',
'icone_repartition_actuelle' => 'Aktuelle Verteilung anzeigen',
'icone_repartition_debut' => 'Seit Einrichtung der Website',
'icone_repartition_visites' => 'Verteilung der Besuche',
'icone_rubriques' => 'Rubriken',
'icone_sauver_site' => 'Website sichern',
'icone_site_entier' => 'Ganze Website',
'icone_sites_references' => 'Verlinkte Websites',
'icone_statistiques' => 'Statistiken',
'icone_statistiques_visites' => 'Statistiken',
'icone_suivi_activite' => 'Aktivit&auml;ten verfolgen',
'icone_suivi_actualite' => 'Entwicklung der Website',
'icone_suivi_forums' => 'Foren verwalten',
'icone_suivi_pettions' => 'Petitionen verwalten',
'icone_suivi_revisions' => '&Auml;nderungen des Artikels',
'icone_supprimer_document' => 'Dokument l&ouml;schen',
'icone_supprimer_image' => 'Bild l&ouml;schen',
'icone_supprimer_message' => 'Nachricht l&ouml;schen',
'icone_tous_articles' => 'Alle Ihre Artikel',
'icone_tous_auteur' => 'Alle Autoren',
'icone_valider_message' => 'Beitrag freigeben',
'icone_visiter_site' => 'Website ansehen',
'icone_voir_en_ligne' => 'Online ansehen',
'image_tourner_180' => 'Um 180&deg; drehen',
'image_tourner_droite' => 'Um 90&deg; nach rechts drehen',
'image_tourner_gauche' => 'Um 90&deg; nach links drehen',
'img_indisponible' => 'Bild nicht vorhanden',
'impossible' => 'unm&ouml;glich',
'info_a_suivre' => 'AUFGABEN &raquo;',
'info_a_valider' => '[zu best&auml;tigen]',
'info_acces_interdit' => 'Zugang gesperrt',
'info_acces_refuse' => 'Zugang verweigert',
'info_action' => 'Aktion: @action@',
'info_administrer_rubriques' => 'Sie k&ouml;nnen diese Rubrik und ihre Unterrubriken verwalten',
'info_adresse_non_indiquee' => 'Sie haben keine Adresse zum Testen agegeben!',
'info_aide' => 'HILFE:',
'info_ajouter_mot' => 'Wort hinzuf&uuml;gen',
'info_annonce' => 'ANK&Uuml;NDIGUNG',
'info_annonces_generales' => 'Allgemeine Ank&uuml;ndigungen:',
'info_article_propose' => 'Vorgeschlagener Artikel',
'info_article_publie' => 'Ver&ouml;ffentlichter Artikel',
'info_article_redaction' => 'Artikel in Bearbeitung',
'info_article_refuse' => 'Abgelehnter Artikel',
'info_article_supprime' => 'Gel&ouml;schter Artikel',
'info_articles' => 'Artikel',
'info_articles_a_valider' => 'Zur Ver&ouml;ffentlichung vorgeschlagenen Artikel',
'info_articles_nb' => '@nb@ Artikel',
'info_articles_proposes' => 'Vorgeschlagene Artikel',
'info_articles_un' => '1 Artikel',
'info_auteurs_nombre' => 'Autor(en):',
'info_authentification_ftp' => 'Authentifizierung per FTP.',
'info_bloquer_lien' => 'Link sperren',
'info_breves_02' => 'Meldungen',
'info_breves_2' => 'Meldungen',
'info_breves_nb' => '@nb@ Meldungen',
'info_breves_un' => '1 Meldung',
'info_breves_valider' => 'Zur Ver&ouml;ffentlichung vorgeschlagene Meldungen',
'info_connexion_refusee' => 'Die Verbindung wurde verweigert.',
'info_contact_developpeur' => 'Bitte kontaktieren Sie einen der Entwickler.',
'info_contenance' => 'Diese Website enth&auml;lt:',
'info_contribution' => 'Forumsbeitr&auml;ge',
'info_copyright' => '@spip@ ist freie Software im Sinne der @lien_gpl@.',
'info_copyright_doc' => 'Weitere Informationen finden Sie unter <a href="@spipnet@">http://www.spip.net/de</a>.',
'info_copyright_gpl' => 'GNU Public License',
'info_cours_edition' => 'Ihre Artikel in Bearbeitung',
'info_creer_repertoire' => 'Bitte legen Sie eine Datei oder ein Verzeichnis mit diesem Namen an: ',
'info_creer_repertoire_2' => '(Im Unterverzeichnis <b>@repertoire@</b>)',
'info_creer_vignette' => 'Miniaturbilder automatisch anlegen',
'info_deplier' => '&Ouml;ffnen',
'info_descriptif_nombre' => 'Beschreibung(en):',
'info_description' => 'Beschreibung:',
'info_description_2' => 'Beschreibung:',
'info_dimension' => 'Ma&szlig;e:',
'info_document' => 'Dokument',
'info_document_indisponible' => 'Dokument nicht verf&uuml;gbar',
'info_documents' => 'Dokumente',
'info_documents_nb' => '@nb@ Dokumente',
'info_documents_un' => '1 Dokument',
'info_echange_message' => 'In SPIP k&ouml;nnen Sie interne Nachrichten austauschen und interne Foren f&uuml;r Teilnehmer der Website anlegen. Diese Funktionen k&ouml;nnen Sie abschalten.',
'info_ecire_message_prive' => 'Neue private Nachricht schreiben',
'info_email_invalide' => 'Ung&uuml;ltige E-Mail Adresse.',
'info_en_cours_validation' => 'Ihre Artikel in Bearbeitung',
'info_en_ligne' => 'Zur Zeit online:',
'info_envoyer_message_prive' => 'Private Nachricht an diesen Autor schicken',
'info_erreur_requete' => 'Abfragefehler: ',
'info_erreur_squelette2' => 'Keine Vorlage <b>@fichier@</b> vorhanden ...',
'info_erreur_systeme' => 'Systemfahler (Fehler no. @errsys@)',
'info_erreur_systeme2' => 'M&ouml;glicherweise ist die Festplatte voll oder die Datenbank besch&auml;digt. <br />
 <font color=\'red\'>Versuchen Sie <a href=\'@script@\'>die Datenbank zu reparieren</a>,
 oder wenden Sie sich an Ihren Provider.</font>',
'info_fini' => 'Fertig!',
'info_format_image' => 'F&uuml;r diese Dateiformate k&ouml;nnen Vorschaubilder erstellt werden: @gd_formats@.',
'info_format_non_defini' => 'Undefiniertes Format',
'info_grand_ecran' => 'Grosser Bildschirm',
'info_image_aide' => 'HILFE',
'info_image_process_titre' => 'Methode zum Anlegen der Miniaturbilder',
'info_impossible_lire_page' => '<b>Fehler!</b> Die Seite <tt><html>@test_proxy@</html></tt> ist nicht &uuml;ber den Proxy erreichbar',
'info_inclusion_directe' => 'Direkte Einbindung:',
'info_inclusion_vignette' => 'Einbindung des Icons:',
'info_installation_systeme_publication' => 'Installation von SPIP ...',
'info_installer_documents' => 'Sie k&ouml;nnen alle Dokumente im Verzeichnis @upload@ automatisch installieren.',
'info_installer_ftp' => 'Als Administrator k&ouml;nnen Sie Dateien (per FTP) direkt in das Verzeichnis <i>@upload@</i> kopieren und sie hier ausw&auml;hlen.',
'info_installer_images' => 'Sie k&ouml;nnen Bilder in den Formaten JPEG, GIF und PNG verwenden.',
'info_installer_images_dossier' => 'Bilder ins Verzeichnis @upload@ kopieren um sie hier ausw&auml;hlen zu k&ouml;nnen.',
'info_installer_tous_documents' => 'Alle Dokumente installieren',
'info_interface_complete' => 'Expertenmodus',
'info_interface_simple' => 'Standardmodus',
'info_joindre_document_article' => 'Diesem Artikel k&ouml;nnen Sie Dokumente folgendem Typs beif&uuml;gen: ',
'info_joindre_document_rubrique' => 'Dieser Rubrik k&ouml;nnen Sie Dokumente folgendem Typs beif&uuml;gen:',
'info_joindre_documents_article' => 'Diesem Artikel k&ouml;nnen Sie Dokumente folgendem Typs beif&uuml;gen:',
'info_l_article' => 'Der Artikel',
'info_la_breve' => 'Die Meldung',
'info_la_rubrique' => 'Die Rubrik',
'info_langue_principale' => 'Hauptsprache der Website',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ Pixel',
'info_les_auteurs_1' => 'von @les_auteurs@ ',
'info_logo_format_interdit' => 'Nur die Logos im Format @formats@ sind zugelassen.',
'info_logo_max_poids' => 'Die Logogr&ouml;sse darf nicht @maxi@ &uuml;berschreiten (aktuelle Dateigr&ouml;sse @actuel@).',
'info_logo_max_taille' => 'Die Logogr&ouml;sse darf nicht @maxi@ &uuml;berschreiten (aktuelle Dateigr&ouml;sse @actuel@).',
'info_mail_fournisseur' => 'IhrName@Server.de',
'info_message_2' => 'NACHRICHT',
'info_message_supprime' => 'NACHRICHT GEL&Ouml;SCHT',
'info_messages_nb' => '@nb@ Nachrichten',
'info_messages_un' => '1 Nachricht',
'info_mise_en_ligne' => 'Online seit:',
'info_modification_parametres_securite' => '&Auml;nderung der Sicherheitseinstellungen',
'info_mois_courant' => 'Im Lauf des Monats:',
'info_mot_cle_ajoute' => 'Das folgende Wort wurde hinzugef&uuml;gt zu',
'info_multi_herit' => 'Standardsprache',
'info_multi_langues_soulignees' => 'Die Texte des Interface sind vollst&auml;ndig in die <u>unterstrichenen Sprachen</u> &uuml;bersetzt. Wenn Sie eine von ihnen w&auml;hlen, werden viele Elemente der Website automatisch &uuml;bersetzt (Datumsangaben, Formulare usw.). In den nicht unterstrichenen Sprachen werden diese Elemente in der Hauptsprache der Website angezeigt.',
'info_multilinguisme' => 'Mehrsprachigkeit',
'info_nom_non_utilisateurs_connectes' => 'Ihr Name wird nicht in der Liste der zur Zeit eingelogten Nutzer angezeigt.',
'info_nom_utilisateurs_connectes' => 'Ihr Name wird in der Liste der angemeldeten Nutzer angezeigt.',
'info_nombre_en_ligne' => 'Zur Zeit online:',
'info_non_resultat' => 'Keine Fundstellen f&uuml;r &#8220;@cherche_mot@&#8221;',
'info_non_utilisation_messagerie' => 'Sie nehmen nicht am Nachrichtensystem der Website teil.',
'info_nouveau_message' => 'SIE HABEN EINE NEUE NACHRICHT',
'info_nouveaux_messages' => 'SIE HABEN @total_messages@ NEUE NACHRICHTEN',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Diese Information ist obligatorisch.',
'info_panne_site_syndique' => 'Syndizierte Website defekt',
'info_pense_bete' => 'MERKZETTEL',
'info_petit_ecran' => 'Kleiner Bildschirm',
'info_petition_close' => 'Petition geschlossen',
'info_pixels' => 'Pixel',
'info_plusieurs_mots_trouves' => 'Mehrere Schlagworte entsprechen Ihrem Suchkriterium &#8220;@cherche_mot@&#8221;:',
'info_popularite_5' => 'Beliebtheit:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'automatische Mappe:',
'info_premier_resultat' => '[@debut_limit@ erste Ergebnisse von @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ erste Ergebnisse von @total@]',
'info_probleme_grave' => 'Problem mit',
'info_propose_1' => '[@nom_site_spip@] vorgeschlagen : @titre@',
'info_propose_2' => 'vorgeschlagener Artikel
---------------',
'info_propose_3' => 'Der Artikel &#8220;@titre@&#8221; ist zur Ver&ouml;ffentlichung vorgeschlagen.',
'info_propose_4' => 'Bitte teilen Sie den anderen Autoren Ihre Meinung zu diesem Artikel mit',
'info_propose_5' => '(im Forum des Artikels). Sie k&ouml;nnen ihn unter dieser Adresse lesen:',
'info_publie_01' => 'Der Artikel &bdquo;@titre@&ldquo; wurde von @connect_nom@ freigegeben.',
'info_publie_1' => '[@nom_site_spip@] VER&Ouml;FFENTLICHT: @titre@',
'info_publie_2' => 'Artikel ver&ouml;ffentlicht
--------------',
'info_rechercher' => 'Suchen',
'info_rechercher_02' => 'Suchen:',
'info_remplacer_vignette' => 'Ersetzen Sie das Standard-Piktogramm durch ein eigenes Logo:',
'info_retablir_lien' => 'Link wieder freigeben',
'info_retirer_mot' => 'Wort entfernen',
'info_retirer_mots' => 'Alle Worte entfernen',
'info_rubriques_nb' => '@nb@ Rubriken',
'info_rubriques_un' => '1 Rubrik',
'info_sans_titre_2' => 'ohne Titel',
'info_selectionner_fichier' => 'Sie k&ouml;nnen eine Datei aus dem Verzeichnis @upload@ ausw&auml;hlen.',
'info_selectionner_fichier_2' => 'W&auml;hlen Sie eine Datei:',
'info_signature_supprimee' => 'Unterschrift gel&ouml;scht',
'info_signature_supprimee_erreur' => 'Fehler: Dieser L&ouml;schcode entspricht keiner Unterschrift.',
'info_site_attente' => 'Websites, die auf Freigabe warten',
'info_site_reference' => 'Verlinkte Website online',
'info_site_refuse' => 'Abgelehnte Website',
'info_sites_nb' => '@nb@ Websites',
'info_sites_referencer' => 'Website verlinken',
'info_sites_un' => '1 Website',
'info_supprimer_vignette' => 'Icon l&ouml;schen',
'info_symbole_bleu' => 'Das <b>blaue</b> Symbol bedeutet <b>Merkzettel</b>, d.h. eine Nachricht nur zu Ihrer eigenen Verwendung.',
'info_symbole_jaune' => 'Das <b>gelbe</b> Symbol bedeutet <b>Ank&uuml;ndigung an alle Redakteure</b> (f&uuml;r alle Redakteure sichtbar, &Auml;nderung nur durch Administratoren)',
'info_symbole_vert' => 'Das <b>gr&uuml;ne</b> Symbol bezeichnet Nachrichten an <b>andere Benutzer</b> der Website.',
'info_syndication' => 'Syndikation:',
'info_syndication_articles' => 'Artikel',
'info_telecharger' => 'Von Ihrem Computer hochladen:',
'info_telecharger_nouveau_logo' => 'Neues Logo hochladen:',
'info_telecharger_ordinateur' => 'Von Ihrem Computer hochladen:',
'info_tous_resultats_enregistres' => ' [alle Ergebnisse sind erfasst]',
'info_tout_afficher' => 'Alles zeigen',
'info_travaux_texte' => 'Diese Website ist noch nicht fertig eingerichtet. Schauen Sie sp&auml;ter mal wieder rein ...',
'info_travaux_titre' => 'Website im Aufbau',
'info_trop_resultat' => 'Zu viele Ergebnisse f&uuml;r &#8220;@cherche_mot&#8221;. Bitte pr&auml;zisieren Sie Ihre Suchbegriffe.',
'info_utilisation_messagerie_interne' => 'Sie verwenden das interne Nachrichtensystem der Website. ',
'info_valider_lien' => 'Link freigeben',
'info_verifier_image' => ', bitte pr&uuml;fen Sie, ob Ihre Bilder fehlerfrei &uuml;bertagen wurden.',
'info_vignette_defaut' => 'Standardsymbol',
'info_vignette_personnalisee' => 'Pers&ouml;nliches Icon',
'info_visite' => 'Besuch:',
'info_visites' => 'Besuche:',
'info_vos_rendez_vous' => 'Ihre kommenden Termine',
'info_zoom' => 'Zoom',
'infos_vos_pense_bete' => 'Ihre Merkzettel', # MODIF
'item_breve_proposee' => 'Vorgeschlagene Meldung',

// L
'lien_afficher_icones_seuls' => 'Nur Piktogramme anzeigen',
'lien_afficher_texte_icones' => 'Piktogramme und Beschriftung anzeigen',
'lien_afficher_texte_seul' => 'Nur Textmen&uuml;s',
'lien_liberer' => 'freigeben',
'lien_liberer_tous' => 'diese Artikel freigeben',
'lien_nouvea_pense_bete' => 'NEUER MERKZETTEL',
'lien_nouveau_message' => 'NEUE NACHRICHT',
'lien_nouvelle_annonce' => 'NEUE ANK&Uuml;NDIGUNG',
'lien_petitions' => 'PETITION',
'lien_popularite' => 'Beliebtheit: @popularite@%',
'lien_racine_site' => 'OBERSTE EBENE DER WEBSITE',
'lien_reessayer' => 'Wiederholen',
'lien_repondre_message' => 'Nachricht beantworten',
'lien_supprimer' => 'L&ouml;schen',
'lien_tout_afficher' => 'Alles zeigen',
'lien_visite_site' => 'Website anzeigen',
'lien_visites' => '@visites@ Besuche',
'lien_voir_auteur' => 'Autor anzeigen',
'ligne' => 'Zeile',
'login' => 'Login',
'login_acces_prive' => 'Login zum Redaktionssystem',
'login_autre_identifiant' => 'Unter anderem Namen anmelden',
'login_cookie_accepte' => 'Bitte stellen Sie Ihren Webbrowser so ein, dass er sie akzeptiert (zumindest f&uuml;r diese Website).',
'login_cookie_oblige' => 'Zu Ihrer Sicherheit muss Ihr Browser Cookies akzeptieren, wenn Sie sich bei der Website anmelden.',
'login_deconnexion_ok' => 'Abmeldung erfolgreich.',
'login_erreur_pass' => 'Passwort oder Benutzername falsch.',
'login_espace_prive' => 'Redaktionssystem',
'login_identifiant_inconnu' => 'Benutzer &laquo;@login@&raquo; unbekannt.',
'login_login' => 'Login:',
'login_login2' => 'Login-Name (zur Anmeldung bei der Website):',
'login_login_pass_incorrect' => '(Login-Name oder Passwort falsch.)',
'login_motpasseoublie' => 'Passwort&nbsp;vergessen?',
'login_non_securise' => 'Achtung, dieses Formular ist nicht abgesichert. Wenn Sie sicher stellen wollen, dass Ihr Passwort nicht im Netzwerk mitgeh&ouml;rt werden kann, aktivieren Sie bitte Javascript und',
'login_nouvelle_tentative' => 'Erneut versuchen',
'login_par_ici' => 'Sie sind angemeldet... hier...',
'login_pass2' => 'Passwort:',
'login_preferez_refuser' => '<b>Wenn Sie keine Cookies verwenden wollen</b>, k&ouml;nnen Sie eine alternative (weniger sichere) Anmeldung nutzen:',
'login_recharger' => 'diese Seite neu laden',
'login_rester_identifie' => 'Anmeldedaten einige Tage merken',
'login_retour_public' => 'Zur&uuml;ck zur &ouml;ffentlichen Website',
'login_retour_site' => 'Zur&uuml;ck zur &ouml;ffentlichen Website',
'login_retoursitepublic' => 'Zur&uuml;ck&nbsp;zur&nbsp;&ouml;ffentlichen&nbsp;Website',
'login_sans_cookiie' => 'Anmeldung ohne Cookies',
'login_securise' => 'Sicheres Login',
'login_sinscrire' => 'anmelden',
'login_test_navigateur' => 'Test Webbrowser/Verbindung',
'login_verifiez_navigateur' => '(&Uuml;berpr&uuml;fen Sie, dass Ihr Webbrowser Ihr Passwort nicht gespeichert hat ...)',

// M
'masquer_colonne' => 'Diese Spalte verbergen',
'masquer_trad' => '&Uuml;bersetzungen ausblenden',
'module_fichiers_langues' => 'Sprachdateien',

// N
'navigateur_pas_redirige' => 'Wenn Ihr Browser keine automatische Weiterleitung unterst&uuml;tzt, klicken Sie hier.',
'numero' => 'Nummer',

// O
'occurence' => 'Vorkommen',
'onglet_affacer_base' => 'Datenbank l&ouml;schen',
'onglet_auteur' => 'Autor',
'onglet_contenu_site' => 'Inhalte der Website',
'onglet_evolution_visite_mod' => 'Entwicklung',
'onglet_fonctions_avances' => 'Erweiterte Einstellungen',
'onglet_informations_personnelles' => 'Pers&ouml;nliche Informationen',
'onglet_interactivite' => 'Interaktivit&auml;t',
'onglet_messagerie' => 'Nachrichtensystem',
'onglet_messages_internes' => 'Interne Nachrichten',
'onglet_messages_publics' => '&Ouml;ffentliche Nachrichten',
'onglet_messages_vide' => 'Nachrichten ohne Text',
'onglet_origine_visites' => 'Ursprung der Besuche',
'onglet_repartition_debut' => 'von Anfang an',
'onglet_repartition_lang' => 'nach Sprachen',
'onglet_repartition_rubrique' => 'Verteilung auf Rubriken',
'onglet_save_restaur_base' => 'Datenbank sichern/wieder herstellen',
'onglet_vider_cache' => 'Sitecache l&ouml;schen',
'ortho_trop_de_fautes2' => 'Korrigieren sie zun&auml;chst die offensichtlichen Fehler und starten dann einen neuen Versuch.',

// P
'pass_choix_pass' => 'Bitte geben Sie Ihr neues Passwort ein:',
'pass_erreur' => 'Fehler',
'pass_erreur_acces_refuse' => '<b>Fehler:</b> Sie haben keinen Zugang mehr zur Website.',
'pass_erreur_code_inconnu' => '<b>Fehler:</b> Angabe entspricht keinem Benutzer mit Zugang zu dieser Website.',
'pass_erreur_non_enregistre' => '<b>Fehler:</b> Die Adresse <tt>@email_oubli@</tt> ist nicht bekannt.',
'pass_erreur_non_valide' => '<b>Fehler:</b> Diese E-Mail Adresse <tt>@email_oubli@</tt> ist ung&uuml;ltig!',
'pass_erreur_probleme_technique' => '<b>Fehler:</b> E-Mail kann aufgrund eines technischen Problems nicht gesendet werden.',
'pass_espace_prive_bla' => 'Das Redaktionssystem dieser Website ist f&uuml;r Besucher zug&auml;nglich, die sich angemeldet haben. Nach erfolgreicher Anmeldung k&ouml;nnen Sie an Artikeln mitarbeiten, eigene Artikel vorschlagen und an allen Diskussionsforen teilnehmen.',
'pass_forum_bla' => 'Sie m&ouml;chten in einem Forum f&uuml;r eingetragene Besucher der Website schreiben.',
'pass_indiquez_cidessous' => 'Bitte geben Sie die E-Mail Adresse an, mit der Sie sich urspr&uuml;nglich eingetragen haben. Sie erhalten dann eine Mail mit allen erforderlichen Schritten um wieder Zugang zu bekommen.',
'pass_mail_passcookie' => '(Diese Nachricht wurde automatisch erzeugt)

Um sich wieder bei der Website
@nom_site_spip@ (@adresse_site@)
anmelden zu k&ouml;nnen, rufen Sie bitte diese Adresse in Ihrem Webbrowser auf:

    @sendcookie@

Sie k&ouml;nnen auf dieser Seite ein neues Passwort eingeben und sich wieder bei der Website einloggen.
',
'pass_mot_oublie' => 'Passwort vergessen',
'pass_nouveau_enregistre' => 'Ihr neues Passwort wurde gespeichert.',
'pass_nouveau_pass' => 'Neues Passwort',
'pass_ok' => 'O.K.',
'pass_oubli_mot' => 'Passwort vergessen',
'pass_quitter_fenetre' => 'Dieses Fenster verlassen',
'pass_rappel_login' => 'Erinnerung: Ihr Login-Name ist &laquo;@login@&raquo;.',
'pass_recevoir_mail' => 'Sie erhalten eine E-Mail mit allen Informationen um wieder Zugang zur Website zu erhalten.',
'pass_retour_public' => 'Zur&uuml;ck zum &ouml;ffentlichen Bereich',
'pass_rien_a_faire_ici' => 'Hier ist nichts zu tun.',
'pass_vousinscrire' => 'Bei dieser Website anmelden',
'precedent' => 'zur&uuml;ck',
'previsualisation' => 'Vorschau',
'previsualiser' => 'Vorschau anzeigen',

// R
'retour' => 'Zur&uuml;ck',

// S
'spip_conforme_dtd' => 'SPIP erkennt dieses Dokument als dem DOCTYPE entsprechend:',
'squelette' => 'Skelett',
'squelette_inclus_ligne' => 'eingebettetes Skelett, Zeile',
'squelette_ligne' => 'Skelett, Zeile',
'stats_visites_et_popularite' => '@visites@ Besuche; Beliebtheit: @popularite@',
'suivant' => 'weiter',

// T
'taille_ko' => '@taille@&nbsp;kB',
'taille_mo' => '@taille@&nbsp;MB',
'taille_octets' => '@taille@&nbsp;Byte',
'texte_actualite_site_1' => 'Wenn Sie sich mit der Oberfl&auml;che des Redaktionssystems vertraut gemacht haben, k&ouml;nnen Sie „',
'texte_actualite_site_2' => 'den Expertenmodus aktivieren,',
'texte_actualite_site_3' => 'um zus&auml;tzliche Funktionen zu nutzen.',
'texte_creation_automatique_vignette' => 'Diese Website generiert automatisch Vorschaubilder. Wenn Sie Bilder in den Formaten @gd_formats@ mit diesem Formular installieren, werden Vorschaubilder mit den maximalen Diemsionen @taille_preview@ Pixel angelegt.',
'texte_documents_associes' => 'Die folgenden Dokumente wurden dem Artikel zugeordnet jedoch nicht direkt in ihn eingef&uuml;gt. Ja nach Gestaltung der &ouml;ffentlichen Website k&ouml;nnen Sie alle beigeordneten Dokumente angezeigt werden (oder auch nicht).',
'texte_erreur_mise_niveau_base' => 'Datenbankfehler beim Einrichten der neuen Version. Das Bild <b>@fichier@</b> wurde nicht &uuml;bernommen (Artikel @id_article@).
 Bitte notieren Sie diesen Hinweis, starten Sie die Aktualisierung erneut und pr&uuml;fen Sie, ob die Bilder
 in den Artikeln angezeigt werden.',
'texte_erreur_visiteur' => 'Sie haben versucht, sich mit einer Identit&auml;t einzuloggen, die dazu nicht berechtigt.',
'texte_inc_auth_1' => 'Sie sind angemeldet als <b>@auth_login@</b>, aber diese ID existiert nicht bzw. nicht mehr in der Datenbank.
 Versuchen Sie,',
'texte_inc_auth_2' => 'sich erneut anzumelden',
'texte_inc_auth_3' => ', nachdem Sie u.U. Ihren Webbrowser neu gestartet haben.',
'texte_inc_config' => 'Die hier m&ouml;glichten Einstellungen beeinflussen das grunds&auml;tzliche Verhalten Ihrer Website. Wir raten dringend, sie nur zu &auml;ndern, wenn Sie vollst&auml;ndig mit der Funktionsweise von SPIP vertraut sind.<br /><br /><b>Es ist ebenfalls mehr als ratsam, diese Einstellungen nur von Ihrem Haupt-Administrator vornehmen zu lassen.</b>',
'texte_inc_meta_1' => 'Das System konnte die Datei <code>@fichier@</code> nicht speichern. Bitte pr&uuml;fen Sie als Administrator ',
'texte_inc_meta_2' => 'die Berechtigungen',
'texte_inc_meta_3' => 'f&uuml;r das Verzeichnis <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'in Bearbeitung',
'texte_statut_poubelle' => 'im M&uuml;lleimer',
'texte_statut_propose_evaluation' => 'vorgeschlagen',
'texte_statut_publie' => 'ver&ouml;ffentlicht',
'texte_statut_refuse' => 'abgelehnt',
'titre_ajouter_mot_cle' => 'SCHLAGWORT ZUORDNEN:',
'titre_breve_proposee' => 'Vorgeschlagene Meldungen',
'titre_breve_publiee' => 'ver&ouml;ffentlichte Meldungen',
'titre_breve_refusee' => 'abgelehnte Meldung',
'titre_cadre_raccourcis' => 'SCHNELLZUGANG:',
'titre_changer_couleur_interface' => 'Farbe der Oberfl&auml;che &auml;ndern',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Sie k&ouml;nnen diesen Artikel verwalten',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'Hilfe zu diesem Element',
'titre_image_auteur_supprime' => 'gel&ouml;schter Autor',
'titre_image_redacteur' => 'Redakteur ohne Systemzugang',
'titre_image_redacteur_02' => 'Redakteur',
'titre_image_visiteur' => 'Besucher',
'titre_joindre_document' => 'DOKUMENT ANF&Uuml;GEN',
'titre_liens_entrants' => 'Referer von heute',
'titre_mots_cles' => 'SCHLAGWORTE',
'titre_probleme_technique' => 'Achtung! Ein Problem mit dem SQL Server verhindert den Zugang zu diesem Teil der Website. Danke f&uuml;r Ihr Verst&auml;ndnis.',
'titre_publier_document' => 'DOKUMENT IN DIESER RUBRIK VER&Ouml;FFENTLICHEN',
'titre_signatures_attente' => 'Nicht best&auml;tigte Unterschriften',
'titre_signatures_confirmees' => 'Best&auml;tigte Unterschriften',
'titre_statistiques' => 'Statistiken',
'titre_titre_document' => 'Titel des Dokuments:',
'todo' => 'demn&auml;chst',
'trad_reference' => '(Referenzartikel)',

// Z
'zbug_balise_b_aval' => '&nbsp;: Tag B muss vor der Schleife stehen',
'zbug_balise_inexistante' => 'Fehler: Der Tag @balise@ wurde nicht richtig f&uuml;r  @from@ deklariert.',
'zbug_balise_sans_argument' => 'Dem Tag @balise@ fehlt ein Parameter',
'zbug_boucle' => 'Schleife',
'zbug_boucle_recursive_undef' => 'Die rekursive Schleife @nom@ ist nicht definiert',
'zbug_calcul' => 'berechnen',
'zbug_champ_hors_boucle' => 'Feld @champ@ ausserhalb einer Schleife',
'zbug_champ_hors_motif' => 'Feld @champ@ befindet sich ausserhalb eines Kontexts @motif@',
'zbug_code' => 'Code',
'zbug_critere_inconnu' => 'Unbekanntes Kriterium @critere@',
'zbug_distant_interdit' => 'Extern unzul&auml;ssig',
'zbug_doublon_table_sans_cle_primaire' => 'Dublette in einer Tabelle ohne eindeutigen Prim&auml;rschl&uuml;ssel',
'zbug_doublon_table_sans_index' => 'Dublette in Tabelle ohne Index',
'zbug_erreur_boucle_double' => 'Schleife (BOUCLE) @id@ doppelt vorhanden',
'zbug_erreur_boucle_fermant' => 'Schleife (BOUCLE) @id@: Schluss-Tag fehlt',
'zbug_erreur_boucle_syntaxe' => 'Syntax der Schleife @id@ fehlerhaft',
'zbug_erreur_compilation' => 'Fehler beim Kompilieren',
'zbug_erreur_execution_page' => 'Fehler beim Ausf&uuml;hren',
'zbug_erreur_filtre' => 'Der Filter @filtre@ ist nicht definiert.',
'zbug_erreur_meme_parent' => 'Das Kriterium {meme_parent} funktioniert nur mit den Schleifen (FORUMS) und (RUBRIQUES).',
'zbug_erreur_squelette' => 'Fehler in Layoutvorlage (Skelett)',
'zbug_hors_compilation' => 'Au&szlig;erhalb der Kompilation',
'zbug_info_erreur_squelette' => 'Irrtum auf der Seite',
'zbug_inversion_ordre_inexistant' => 'Umkehrung einer inexistenten Sortierung ',
'zbug_pagination_sans_critere' => '#PAGINATION ohne Kriterium {pagination} oder in rekursiver Schleife',
'zbug_parametres_inclus_incorrects' => 'INCLUDE-Parameter fehlerhaft: @param@',
'zbug_profile' => 'Rechenzeit: @time@',
'zbug_resultat' => 'Ergebnis',
'zbug_serveur_indefini' => 'SQL-Server nicht definiert',
'zbug_statistiques' => 'Statistik der SQL Abfragen nach Dauer',
'zbug_table_inconnue' => 'SQL-Tabelle &laquo; @table@ &raquo; unbekannt',
'zxml_connus_attributs' => 'bekannte Attribute',
'zxml_de' => 'von',
'zxml_inconnu_attribut' => 'Attribut unbekannt',
'zxml_inconnu_balise' => 'Tag unbekannt',
'zxml_inconnu_entite' => 'Entity unbekannt',
'zxml_inconnu_id' => 'ID unbekannt',
'zxml_mais_de' => 'aber',
'zxml_non_conforme' => 'entspricht nicht dem Motiv',
'zxml_non_fils' => 'ist kein Kind von',
'zxml_nonvide_balise' => 'kein leerer Tag',
'zxml_obligatoire_attribut' => 'obligatorisches Attribut fehlt in',
'zxml_succession_fils_incorrecte' => 'Objektreihenfolge inkorrekt',
'zxml_survoler' => 'Mouseover zeigt korrekte',
'zxml_valeur_attribut' => 'Attributwert',
'zxml_vide_balise' => 'leerer Tag',
'zxml_vu' => 'bereits gesehen'
);

?>
